% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/clustering.R
\name{clusterTimeSeries}
\alias{clusterTimeSeries}
\title{Cluster time series features.}
\usage{
clusterTimeSeries(
  object,
  n.top.feat = 1000,
  groups.selected = "all",
  lambda = c(0.5, 0.25),
  clust.params = list()
)
}
\arguments{
\item{object}{A \code{TimeSeriesExperiment} object}

\item{n.top.feat}{A number of top most variable time-course features to use
for clustering.}

\item{groups.selected}{One or multiple groups from \code{object@group} 
to take into account when aggregating time-course features.}

\item{lambda}{Weights for each lag difference, for time-course data.
Length of \code{lambda} specifies number of lags to include. By default
lag of order one and two are included with coefficients 0.5 and 0.25
respectively.}

\item{clust.params}{A list contating arguments for hierarchical clustering.
For details see \code{\link{clusterData}}.}
}
\value{
a \code{TimeSeriesExperiment} object with cluster assignment stored
in \code{cluster.map} slot.
}
\description{
Find the cluster assignment for timecourse features.
Clustering computed for top "n.top.feat" features most variable over time
in each of the selected "groups" using time-series expression 
(collpased over replicates). The cluster assignment of the remaining
genes is based on the distance to the closest cluster centroid previously
obtained. Hierarchical clustering is performed and both static and dynamic
branch cutting algorithm are available for assigning cluster membership.
}
\examples{
data("endoderm_small")
endoderm_small <- clusterTimeSeries(endoderm_small)
head(clusterMap(endoderm_small))

}
